use bevy::{diagnostic::FrameTimeDiagnosticsPlugin, prelude::*, ui::FocusPolicy};

fn main() {
    App::new()
        .add_plugins((DefaultPlugins, FrameTimeDiagnosticsPlugin))
        .add_systems(Startup, setup)
        .run();
}

fn setup(mut commands: Commands, asset_server: Res<AssetServer>) {
    commands.spawn(Camera2dBundle::default());

    commands
        .spawn((
            Interaction::None,
            NodeBundle {
                style: Style {
                    position_type: PositionType::Absolute,
                    flex_direction: FlexDirection::Column,
                    align_self: AlignSelf::Center,
                    width: Val::Percent(100.0),
                    height: Val::Percent(100.0),
                    padding: UiRect::all(Val::Px(8.0)),
                    ..Default::default()
                },
                focus_policy: FocusPolicy::Block,
                background_color: Color::rgb(0.9, 0.9, 0.9).into(),
                ..Default::default()
            },
        ))
        .with_children(|parent| {
            parent.spawn(NodeBundle {
                style: Style {
                    justify_content: JustifyContent::Center,
                    ..Default::default()
                },
                ..Default::default()
            });

            parent
                .spawn(NodeBundle {
                    style: Style {
                        padding: UiRect::all(Val::Px(15.0)),
                        column_gap: Val::Px(10.0),
                        ..Default::default()
                    },
                    ..Default::default()
                })
                .with_children(|parent| {
                    parent.spawn(TextBundle::from_section(
                        "Debug collisions",
                        TextStyle {
                            font: asset_server.load("fonts/FiraSans-Bold.ttf"),
                            font_size: 25.0,
                            color: Color::rgb(0.1, 0.1, 0.1),
                        },
                    ));
                });
        });
}
